@@ -1,5 +1,7 @@
 import requests
+from urllib3.exceptions import InsecureRequestWarning
 
+requests.packages.urllib3.disable_warnings(category=InsecureRequestWarning)
 
 class HttpClient:
     """Client for handling requests to Tonic instance
