@@ -8,17 +8,12 @@ class ModelService:
     def get_trained_model(self, job_id: str):
         return self.client.http_get("/api/modeltraining/models/" + job_id)
     
-    def get_most_recent_trained_model(self, model_id: str):
-        return self.client.http_get(
-            "/api/modeltraining/most_recent_trained_model/" + model_id
-        )
-    
-    def get_most_recent_trained_model_old(self, workspace_id: str, model_id: str):
+    def get_most_recent_trained_model(self, workspace_id: str, model_id: str):
         params = {"workspaceId": workspace_id, "modelId": model_id}
         return self.client.http_get(
-            "/api/modeltraining/most_recent_trained_model_old", params=params
+            "/api/modeltraining/most_recent_trained_model", params=params
         )
-
+    
     def sample(self, model_training_id: str, num_rows: int):
         params = {"numRows": num_rows} if num_rows is not None else {}
         return self.client.http_get(
